AudioManagerPlugin class

Constructors

AudioManagerPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
players ↔ Map<String, WrappedPlayer>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrCreatePlayer(String playerId) → WrappedPlayer
handleMethodCall(MethodCall call) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String playerId, String url) → WrappedPlayer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void